# logsensei

Personal Wrapper on Loguru

[![Build Status](https://travis-ci.org/AdityaSidharta/logsensei.svg?branch=master)](https://travis-ci.org/AdityaSidharta/logsensei) [![Codacy Badge](https://api.codacy.com/project/badge/Grade/315315d588c745929c5a3093d2b92850)](https://www.codacy.com/manual/AdityaSidharta/logsensei?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=AdityaSidharta/logsensei&amp;utm_campaign=Badge_Grade) 
[![codecov](https://codecov.io/gh/AdityaSidharta/logsensei/branch/master/graph/badge.svg)](https://codecov.io/gh/AdityaSidharta/logsensei)[![Documentation](https://img.shields.io/badge/docs-passing-Green)](https://adityasidharta.com/logsensei/)

